import Foundation

enum FileType {
    case image(ImageType)

    case file(String)
    case video(VideoType)
    case resource(String)


    init(fileExtension: String?) {
        guard let ext = fileExtension?.lowercased() else {
            self = .file("")
            return
        }
        switch ext {
        case "jpg", "jpeg":
            self = .image(.jpg)
        case "png":
            self = .image(.png)
        case "avif":
            self = .image(.avif)
        case "webp":
            self = .image(.webp)
        case "gif":
            self = .image(.gif)
        case "html", "stl", "f3d", "step", "f3z", "zip", "json", "conf", "css", "js", "cpp", "cddx", "svg", "glb", "mp3", "pdf", "swift":
            self = .file(ext)
        case "mp4":
            self = .video(.mp4)
        case "m4v":
            self = .video(.m4v)
        case "webm":
            self = .video(.webm)
        case "key", "psd":
            self = .resource(ext)
        default:
            print("Unhandled file type: \(ext)")
            self = .resource(ext)
        }
    }

    var fileExtension: String {
        switch self {
        case .image(let imageType): return imageType.fileExtension
        case .video(let videoType): return videoType.fileExtension
        default:
            return "" // TODO: Fix
        }
    }

    var isImage: Bool {
        if case .image = self {
            return true
        }
        return false
    }

    var isVideo: Bool {
        if case .video = self {
            return true
        }
        return false
    }

    var videoType: VideoType? {
        if case .video(let videoType) = self {
            return videoType
        }
        return nil
    }
}
