import SwiftUI

struct PageDetailView: View {

    @Environment(\.language)
    private var language

    @ObservedObject
    private var item: Page

    init(page: Page) {
        self.item = page
    }

    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                Text("ID")
                    .font(.headline)
                TextField("", text: $item.id)
                    .textFieldStyle(.roundedBorder)
                    .padding(.bottom)

                HStack {
                    Text("Draft")
                        .font(.headline)
                    Spacer()
                    Toggle("", isOn: $item.isDraft)
                        .toggleStyle(.switch)
                }
                .padding(.bottom)

                HStack {
                    Text("Start")
                        .font(.headline)
                    Spacer()
                    DatePicker("", selection: $item.startDate, displayedComponents: .date)
                        .datePickerStyle(.compact)
                        .padding(.bottom)
                }

                HStack(alignment: .firstTextBaseline) {
                    Text("Has end date")
                        .font(.headline)
                    Spacer()
                    Toggle("", isOn: $item.hasEndDate)
                        .toggleStyle(.switch)
                        .padding(.bottom)
                }

                if item.hasEndDate {
                    HStack(alignment: .firstTextBaseline) {
                        Text("End date")
                            .font(.headline)
                        Spacer()
                        DatePicker("", selection: $item.endDate, displayedComponents: .date)
                            .datePickerStyle(.compact)
                            .padding(.bottom)
                    }
                }

                LocalizedPageDetailView(page: item.localized(in: language))

            }
            .padding()
        }
    }
}

#Preview {
    PageDetailView(page: .empty)
}
