import SwiftUI

struct DatePickerView: View {

    @ObservedObject
    var post: Post

    @Binding var showDatePicker: Bool

    var body: some View {
        NavigationView {
            VStack {
                HStack(alignment: .top) {
                    VStack {
                        Text("Start date")
                            .font(.headline)
                            .padding(.vertical, 3)
                        DatePicker("", selection: $post.startDate, displayedComponents: .date)
                            .datePickerStyle(GraphicalDatePickerStyle())
                            .labelsHidden()
                            .padding()

                    }

                    VStack {
                        Toggle("End date", isOn: $post.hasEndDate)
                            .toggleStyle(.switch)
                            .font(.headline)
                        DatePicker("Select a date", selection: $post.startDate, displayedComponents: .date)
                            .datePickerStyle(GraphicalDatePickerStyle())
                            .labelsHidden()
                            .padding()
                            .disabled(!post.hasEndDate)
                    }
                }
                Button("Done") {
                    showDatePicker = false
                }
                Spacer()
            }
            .navigationTitle("Pick a Date")
            .padding()
        }
    }
}

#Preview {
    DatePickerView(post: .mock, showDatePicker: .constant(true))
}
