import Foundation
import SwiftUI
import SFSafeSymbols

struct TagView: View {

    @Environment(\.language)
    var language: ContentLanguage

    let tag: LocalizedText

    init(tag: LocalizedText) {
        self.tag = tag
    }

    static var add: TagView {
        .init(tag: LocalizedText(en: "Add", de: "Mehr"))
    }

    var body: some View {
        HStack {
            Text(tag.getText(for: language))
                .font(.subheadline)
                .padding(.leading, 2)
        }
        .font(.caption2)
        .padding(.horizontal, 8)
        .padding(.vertical, 4)
        .background(Color.accentColor)
        .cornerRadius(8)
    }
}

#Preview {
    HStack {
        TagView(tag: LocalizedText(en: "Some", de: "Etwas"))
            .environment(\.language, ContentLanguage.german)
        TagView(tag: LocalizedText(en: "Some", de: "Etwas"))
            .environment(\.language, ContentLanguage.english)
        TagView.add
    }.background(Color.secondary)
}
