import SwiftUI

private struct SelectedTagView: View {

    @Environment(\.language)
    private var language

    @ObservedObject
    var tag: Tag

    var body: some View {
        TagDetailView(
            tagIsVisible: $tag.isVisible,
            tag: tag.localized(in: language))
    }
}

struct TagsListView: View {

    @Environment(\.language)
    var language

    @EnvironmentObject
    var content: Content

    @State
    var selectedTag: Tag?

    var body: some View {
        NavigationSplitView {
            List(content.tags.sorted(), selection: $selectedTag) { tag in
                Text(tag.localized(in: language).name)
                    .tag(tag)
            }
        } content: {
            if let selectedTag {
                TagContentView(tag: selectedTag)
                    .layoutPriority(1)
            } else {
                Text("Select a tag to show the details")
                    .font(.largeTitle)
                    .foregroundColor(.secondary)
            }
        } detail: {
            if let selectedTag {
                SelectedTagView(tag: selectedTag)
                    .frame(maxWidth: 350)
            } else {
                EmptyView()
            }
        }
        .onAppear {
            if selectedTag == nil {
                selectedTag = content.tags.first
            }
        }
        .toolbar {
            ToolbarItem(placement: .primaryAction) {
                Button(action: addNewTag) {
                    Label("New tag", systemSymbol: .plus)
                }
            }
        }
    }

    private func addNewTag() {
        let newTag = Tag(isVisible: true,
                         german: .init(urlComponent: "tag", name: "Neuer Tag"),
                         english: .init(urlComponent: "tag-en", name: "New Tag"))
        // Add to top of the list, and resort when changing the name
        content.tags.insert(newTag, at: 0)
    }
}

#Preview {
    PageListView()
        .environmentObject(Content())
}
